@@ -593,6 +593,13 @@ export class CopyAttrsComponent implements OnInit, OnDestroy, AfterViewInit {
         if (value === undefined) {
             value = this.values[field];
         } else {
+            // If the field is number-ish, the empty string means null. Force that here.
+            // ??? Should all fields be forced to null on empty string?
+            if (value === '' &&
+                ['float','int','number','money'].includes(this.idl.classes.acp.field_map[field]?.datatype)
+            ) {
+                value = null;
+            }
             this.values[field] = value;
         }
 
@@ -811,10 +818,16 @@ export class CopyAttrsComponent implements OnInit, OnDestroy, AfterViewInit {
                     }
                     // console.debug('vol ' + copy.call_number().id(), copy.call_number());
                 } else {
-                    const copyValue = this.idl.pkeyValue(copy[fieldName]());
-                    const origCopyValue = this.idl.pkeyValue(originalCopy[fieldName]());
-                    // Restore copy field from the original
-                    copy[fieldName](origCopyValue);
+                    if (this.templateOnlyMode) {
+                        // all we do in this mode is clear the value
+                        this.applyCopyValue(fieldName, null);
+                    } else {
+                        // Restore copy field from the original
+                        // When not in template editing mode we need to deal with objects
+                        // (like acpl) when present rather than only IDs.
+                        const origCopyValue = originalCopy[fieldName]();
+                        copy[fieldName](origCopyValue);
+                    }
                 }
 
                 this.idl.classes['acp'].fields.forEach(idlField => {
